@@ -590,11 +590,14 @@ class BaseFactorModel(pl.LightningModule):
         """
         pass
     
+    @abstractmethod
     def update(
         self,
         X_std: np.ndarray,
         *,
-        kalman_filter: Optional[Any] = None
+        history: Optional[int] = None,
+        kalman_filter: Optional[Any] = None,
+        scaler: Optional[Any] = None
     ) -> 'BaseFactorModel':
         """Update factor state with standardized data.
         
@@ -608,8 +611,16 @@ class BaseFactorModel(pl.LightningModule):
             Standardized data array (T x N), where T is number of time periods
             and N is number of series. Data should already be standardized using
             result.Mx and result.Wx.
+        history : int, optional
+            Number of recent periods to use for factor state update. If None, uses
+            all provided data (default). If specified (e.g., 60), uses only the most
+            recent N periods. Initial state (Z_0, V_0) is always estimated from
+            full training data, but the update uses only recent history for efficiency.
         kalman_filter : Any, optional
             Kalman filter instance. If None, uses default or model's kalman filter.
+        scaler : Any, optional
+            If provided, attach/replace the model's scaler (e.g., refit on new regime).
+            When None, keep the existing scaler from training.
             
         Returns
         -------
@@ -620,48 +631,11 @@ class BaseFactorModel(pl.LightningModule):
         --------
         >>> # Update state with new data, then predict
         >>> model.update(X_std).predict(horizon=1)
-        >>> # Or update and predict separately
-        >>> model.update(X_std)
+        >>> # Or update with only recent 12 periods
+        >>> model.update(X_std, history=12)
         >>> forecast = model.predict(horizon=6)
         """
-        self._check_trained()
-        
-        result = self.result  # Use property which ensures non-None after _check_trained()
-        
-        # Validate input shape
-        if not isinstance(X_std, np.ndarray):
-            X_std = np.asarray(X_std)
-        if X_std.ndim != 2:
-            raise ValueError(
-                f"{self.__class__.__name__} update(): X_std must be 2D array (T x N), "
-                f"got shape {X_std.shape}"
-            )
-        
-        # Handle NaN/Inf values
-        X_std = np.where(np.isfinite(X_std), X_std, np.nan)
-        
-        # Update factor state (model-specific)
-        if hasattr(self, 'encoder') and self.encoder is not None:
-            # DDFM: Extract factors via encoder, then use Kalman filter
-            Z_last_updated = self._update_factor_state_ddfm(
-                X_std, result, kalman_filter
-            )
-        else:
-            # DFM: Use Kalman filter directly on standardized data
-            Z_last_updated = self._update_factor_state_dfm(
-                X_std, result, kalman_filter or getattr(self, 'kalman', None)
-            )
-        
-        # Update result.Z[-1, :] permanently
-        if Z_last_updated is not None:
-            result.Z[-1, :] = Z_last_updated
-        else:
-            _logger.warning(
-                f"{self.__class__.__name__} update(): Failed to update factor state, "
-                f"keeping current state"
-            )
-        
-        return self
+        pass
     
     def get_result(self) -> BaseResult:
         """Extract result from trained model.
