@@ -89,6 +89,7 @@ class DFM(BaseFactorModel):
         max_iter: int = 100,
         nan_method: int = 2,
         nan_k: int = 3,
+        tent_weights_dict: Optional[dict] = None,
         **kwargs
     ):
         """Initialize DFM instance.
@@ -119,6 +120,8 @@ class DFM(BaseFactorModel):
         self.max_iter = max_iter
         self.nan_method = nan_method
         self.nan_k = nan_k
+        # Optional tent weights to control aggregation (e.g., disable tent by passing {'q':[1.0]})
+        self.tent_weights_dict = tent_weights_dict
         
         # Determine number of factors
         if num_factors is None:
@@ -200,7 +203,7 @@ class DFM(BaseFactorModel):
             nQ=0,
             i_idio=None,
             clock=getattr(self.config, 'clock', 'm'),
-            tent_weights_dict=None,
+            tent_weights_dict=self.tent_weights_dict,
             frequencies=None,
             idio_chain_lengths=None,
             config=self.config
@@ -280,7 +283,7 @@ class DFM(BaseFactorModel):
             nQ=0,
             i_idio=torch.ones(y.shape[0], device=y.device, dtype=y.dtype),
             blocks=self.blocks.to(y.device),
-            tent_weights_dict={},
+            tent_weights_dict=self.tent_weights_dict,
             clock=getattr(self.config, 'clock', 'm'),
             frequencies=None,
             idio_chain_lengths=torch.zeros(y.shape[0], device=y.device, dtype=y.dtype),
@@ -664,7 +667,9 @@ class DFM(BaseFactorModel):
     def on_train_start(self) -> None:
         """Called when training starts. Run EM algorithm."""
         # Get processed data and standardization params from DataModule
-        X_torch, Mx, Wx = self._get_data_from_datamodule()
+        data_module = self._get_datamodule()
+        X_torch = data_module.get_processed_data()
+        Mx, Wx = data_module.get_std_params()
         
         # Run EM algorithm
         self.fit_em(X_torch, Mx=Mx, Wx=Wx)
@@ -830,6 +835,21 @@ class DFM(BaseFactorModel):
                             f"(max deviation: {max_deviation:.1f} std devs). "
                             f"Possible numerical instability."
                         )
+        
+        # Convert to numpy (handles torch inputs) and attempt scaler inverse_transform if available
+        X_forecast = np.asarray(
+            X_forecast.detach().cpu().numpy() if hasattr(X_forecast, "detach") else X_forecast
+        )
+        scaler = getattr(self, "scaler", None)
+        if scaler is not None and hasattr(scaler, "inverse_transform"):
+            try:
+                X_forecast = scaler.inverse_transform(X_forecast)
+            except Exception as e:
+                _logger.warning(
+                    f"DFM prediction: scaler.inverse_transform failed, returning unstandardized values. "
+                    f"error={e}"
+                )
+        
         if return_factors and np.any(~np.isfinite(Z_forecast)):
             nan_count = np.sum(~np.isfinite(Z_forecast))
             raise ValueError(
@@ -844,6 +864,100 @@ class DFM(BaseFactorModel):
             return X_forecast
         return Z_forecast
     
+    def update(
+        self,
+        X_std: np.ndarray,
+        *,
+        history: Optional[int] = None,
+        kalman_filter: Optional[Any] = None,
+        scaler: Optional[Any] = None
+    ) -> 'DFM':
+        """Update factor state with standardized data.
+        
+        This method permanently updates the last factor state (result.Z[-1, :])
+        using the provided standardized data. Users should handle all preprocessing
+        (masking, imputation, standardization) before calling this method.
+        
+        Parameters
+        ----------
+        X_std : np.ndarray
+            Standardized data array (T x N), where T is number of time periods
+            and N is number of series. Data should already be standardized using
+            result.Mx and result.Wx.
+        history : int, optional
+            Number of recent periods to use for factor state update. If None, uses
+            all provided data (default). If specified (e.g., 60), uses only the most
+            recent N periods. Initial state (Z_0, V_0) is always estimated from
+            full training data, but the update uses only recent history for efficiency.
+        kalman_filter : Any, optional
+            Kalman filter instance. If None, uses default or model's kalman filter.
+            
+        Returns
+        -------
+        DFM
+            Self for method chaining
+            
+        Examples
+        --------
+        >>> # Update state with new data, then predict
+        >>> model.update(X_std).predict(horizon=1)
+        >>> # Or update with only recent 12 periods
+        >>> model.update(X_std, history=12)
+        >>> forecast = model.predict(horizon=6)
+        """
+        self._check_trained()
+        
+        # Optionally replace scaler (e.g., if refit on new regime)
+        if scaler is not None:
+            self.scaler = scaler
+        
+        result = self.result  # Use property which ensures non-None after _check_trained()
+        
+        # Validate input shape
+        if not isinstance(X_std, np.ndarray):
+            X_std = np.asarray(X_std)
+        if X_std.ndim != 2:
+            raise ValueError(
+                f"DFM update(): X_std must be 2D array (T x N), "
+                f"got shape {X_std.shape}"
+            )
+        
+        # Handle NaN/Inf values
+        X_std = np.where(np.isfinite(X_std), X_std, np.nan)
+        
+        # Filter to recent history if specified
+        # Note: Initial state (Z_0, V_0) from result is estimated from full training data,
+        # but we use only recent history for the update step
+        if history is not None and history > 0:
+            if X_std.shape[0] > history:
+                X_recent = X_std[-history:, :]
+                _logger.debug(
+                    f"DFM update(): Using {history} most recent periods out of {X_std.shape[0]} total periods"
+                )
+            else:
+                X_recent = X_std
+                _logger.debug(
+                    f"DFM update(): history={history} specified but data has only {X_std.shape[0]} periods, using all data"
+                )
+        else:
+            X_recent = X_std
+        
+        # Update factor state using Kalman filter directly on standardized data
+        Z_last_updated = self._update_factor_state_dfm(
+            X_recent, result, kalman_filter or getattr(self, 'kalman', None)
+        )
+        
+        # Update result.Z[-1, :] permanently
+        if Z_last_updated is not None:
+            result.Z[-1, :] = Z_last_updated
+        else:
+            _logger.warning(
+                f"DFM update(): Failed to update factor state, "
+                f"keeping current state"
+            )
+            
+        return self
+    
     @property
     def result(self) -> DFMResult:
         """Get model result from training state.
@@ -863,8 +977,5 @@ class DFM(BaseFactorModel):
         """Reset model state."""
         super().reset()
         return self
-    
-    # nowcast() is inherited from BaseFactorModel
-    
 
 
